<?php
/**
 * Main plugin file.
 * Additions for the Prose Child Theme for Genesis Framework: Widgetized
 *    Homepage, layouts, menu positions, translation loading, plus various
 *    helpers.
 *
 * @package   Genesis Prose Extras
 * @author    David Decker
 * @link      http://twitter.com/deckerweb
 * @copyright Copyright (c) 2013, David Decker - DECKERWEB
 *
 * Plugin Name: Genesis Prose Extras
 * Plugin URI: http://genesisthemes.de/en/wp-plugins/genesis-prose-extras/
 * Description: Additions for the Prose Child Theme for Genesis Framework: Widgetized Homepage, layouts, menu positions, translation loading, plus various helpers.
 * Version: 1.1.0
 * Author: David Decker - DECKERWEB
 * Author URI: http://deckerweb.de/
 * License: GPL-2.0+
 * License URI: http://www.opensource.org/licenses/gpl-license.php
 * Text Domain: genesis-prose-extras
 * Domain Path: /languages/
 *
 * Copyright (c) 2013 David Decker - DECKERWEB
 *
 *     This file is part of Genesis Prose Extras,
 *     a plugin for WordPress.
 *
 *     Genesis Prose Extras is free software:
 *     You can redistribute it and/or modify it under the terms of the
 *     GNU General Public License as published by the Free Software
 *     Foundation, either version 2 of the License, or (at your option)
 *     any later version.
 *
 *     Genesis Prose Extras is distributed in the hope that
 *     it will be useful, but WITHOUT ANY WARRANTY; without even the
 *     implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 *     PURPOSE. See the GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with WordPress. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Prevent direct access to this file.
 *
 * @since 1.0.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


/**
 * Setting constants
 *
 * @since 1.0.0
 */
/** Set plugin version */
define( 'GPEX_VERSION', ddw_gpex_plugin_get_data( 'Version' ) );

/** Plugin directory */
define( 'GPEX_PLUGIN_DIR', dirname( __FILE__ ) );

/** Plugin base directory */
define( 'GPEX_PLUGIN_BASEDIR', dirname( plugin_basename( __FILE__ ) ) );

/** Plugin template directory */
define( 'GPEX_TEMPLATE_DIR', dirname( __FILE__ ) . '/templates' );

/** Set constant/ filter for plugin's languages directory */
define(
	'GPEX_LANG_DIR',
	apply_filters( 'gpex_filter_lang_dir', GPEX_PLUGIN_BASEDIR . '/languages/' )
);

/** Required Version of Genesis Framework */
define( 'GPEX_REQUIRED_GENESIS', '1.8.2' );

/** Required Version of Genesis Framework */
define( 'GPEX_REQUIRED_PROSE', '1.5.0' );

/** Dev scripts & styles on Debug, minified on production */
define(
	'GPEX_SCRIPT_SUFFIX',
	( ( defined( 'WP_DEBUG' ) && ! WP_DEBUG ) || ( defined( 'SCRIPT_DEBUG' ) && ! SCRIPT_DEBUG ) ) ? '.min' : ''
);


register_activation_hook( __FILE__, 'ddw_gpex_activation' );
/**
 * Check the environment when plugin is activated.
 *   - Requirements: Genesis Framework plus Prose Child Theme needs to be installed and activated.
 *   - Note: register_activation_hook() isn't run after auto or manual upgrade, only on activation!
 *
 * @since  1.0.0
 *
 * @uses   load_plugin_textdomain()
 * @uses   deactivate_plugins()
 * @uses   plugin_basename()
 * @uses   wp_die()
 *
 * @param  $gpex_genesis_prose_deactivation_message
 * @param  $gpex_prose_deactivation_message
 * @param  $gpex_prose_link
 * @param  $gpex_prose_required
 *
 * @return string Optional plugin activation messages for the user.
 */
function ddw_gpex_activation() {

	/** Load translations to display for the activation message. */
	load_plugin_textdomain( 'genesis-prose-extras', false, GPEX_LANG_DIR );

	/** Helper variables */
	$gpex_prose_link = '<a href="http://deckerweb.de/go/genesis-prose-child-theme/" target="_new"><strong><em>' . __( 'Prose', 'genesis-prose-extras' ) . '</em></strong></a>';
	$gpex_prose_required = '<code>' . GPEX_REQUIRED_PROSE . '</code>';

	/** Check for activated "Genesis Framework" (= template/parent theme) plus "Prose" child theme */
	if ( ( basename( get_template_directory() ) != 'genesis' )
		&& ! class_exists( 'Genesis_Admin_Boxes' )
		&& ! defined( 'PROSE_DOMAIN' )
	) {

		/** If no Genesis & Prose, deactivate ourself */
		deactivate_plugins( plugin_basename( __FILE__ ) );

		/** Message: no Genesis active */
		$gpex_genesis_prose_deactivation_message = sprintf(
			__( 'Sorry, you cannot activate the %1$s plugin unless you have installed the latest version of the %2$sGenesis Framework%3$s (at least %4$s) and the %5$s child theme (at least %6$s).', 'genesis-prose-extras' ),
			__( 'Genesis Prose Extras', 'genesis-prose-extras' ),
			'<a href="http://deckerweb.de/go/genesis/" target="_new"><strong><em>',
			'</em></strong></a>',
			'<code>' . GPEX_REQUIRED_GENESIS . '</code>',
			$gpex_prose_link,
			$gpex_prose_required
		);

		/** Deactivation message */
		wp_die(
			$gpex_genesis_prose_deactivation_message,
			__( 'Plugin', 'genesis-prose-extras' ) . ': ' . __( 'Genesis Prose Extras', 'genesis-prose-extras' ),
			array( 'back_link' => true )
		);

	} elseif ( ! is_multisite()
		&& ( basename( get_template_directory() ) == 'genesis' )
		&& class_exists( 'Genesis_Admin_Boxes' )
		&& ! defined( 'PROSE_DOMAIN' )
	) {

		/** If Genesis but no Prose, still, deactivate ourself */
		deactivate_plugins( plugin_basename( __FILE__ ) );

		/** Message: no Genesis active */
		$gpex_prose_deactivation_message = sprintf(
			__( 'You\'re in luck, since you have already installed the Genesis Framework! :) However, you cannot activate the %1$s plugin unless you have also installed the latest version of the %2$s child theme (at least %3$s).', 'genesis-prose-extras' ),
			__( 'Genesis Prose Extras', 'genesis-prose-extras' ),
			$gpex_prose_link,
			$gpex_prose_required
		);

		/** Deactivation message */
		wp_die(
			$gpex_prose_deactivation_message,
			__( 'Plugin', 'genesis-prose-extras' ) . ': ' . __( 'Genesis Prose Extras', 'genesis-prose-extras' ),
			array( 'back_link' => true )
		);

	}  // end-if Genesis check


}  // end of function ddw_gpex_activation


add_action( 'plugins_loaded', 'ddw_gpex_translations_init' );
/**
 * Load the textdomain for translation of the plugin - load it early.
 *   - Hook 'plugins_loaded' for proper translations display in plugin settings admin.
 *   - Also include the Translations loader for Prose child theme.
 * 
 * @since  1.0.0
 *
 * @uses   is_admin()
 * @uses   load_textdomain()	To load translations first from WP_LANG_DIR sub folder.
 * @uses   load_plugin_textdomain() To additionally load default translations from plugin folder (default).
 *
 * @param  string 	$gpex_textdomain
 * @param  string 	$plugin_locale
 * @param  string 	$gpex_wp_lang_dir
 *
 * @global mixed $locale
 */
function ddw_gpex_translations_init() {

	/** Load translations for the plugin - only needed within '/wp-admin/' */
	if ( is_admin() ) {

		/** Set unique textdomain string */
		$gpex_textdomain = 'genesis-prose-extras';

		/** The 'plugin_locale' filter is also used by default in load_plugin_textdomain() */
		$plugin_locale = apply_filters( 'plugin_locale', get_locale(), $gpex_textdomain );

		/** Set filter for WordPress languages directory */
		$gpex_wp_lang_dir = apply_filters(
			'gpex_filter_wp_lang_dir',
			WP_LANG_DIR . '/genesis-prose-extras/' . $gpex_textdomain . '-' . $plugin_locale . '.mo'
		);

		/** Translations: First, look in WordPress' "languages" folder = custom & update-secure! */
		load_textdomain( $gpex_textdomain, $gpex_wp_lang_dir );

		/** Translations: Secondly, look in plugin's "languages" folder = default */
		load_plugin_textdomain( $gpex_textdomain, FALSE, GPEX_LANG_DIR );

	}  // end-if is_admin() check

	/** Init global variable for locale check */
	global $locale;

	/** Load update-secure and/or custom translations for Prose backend/frontend */
	if ( ( ! empty( $locale ) && !( get_locale() == 'en_US' || get_locale() == 'en_GB' || get_locale() == 'en_NZ' || get_locale() == 'en' ) )
	) {

		require_once( GPEX_PLUGIN_DIR . '/includes/gpex-translations-loader.php' );

	}  // end-if locale checks

}  // end of function ddw_gpex_translations_init


add_action( 'init', 'ddw_gpex_init', 1 );
/**
 * Load admin helper functions - only within 'wp-admin'.
 * 
 * @since 1.0.0
 *
 * @uses  is_admin()
 * @uses  current_user_can()
 */
function ddw_gpex_init() {

	/** Define constants and set defaults for enabling specific stuff */
	if ( ! defined( 'GPEX_NO_WIDGETS_SHORTCODE' ) ) {
		define( 'GPEX_NO_WIDGETS_SHORTCODE', FALSE );
	}

	if ( ! defined( 'GPEX_NO_EXPORT_IMPORT_INFO' ) ) {
		define( 'GPEX_NO_EXPORT_IMPORT_INFO', FALSE );
	}

	/** Include admin & frontend functions when needed */
	if ( is_admin() ) {

		/** Admin only helper functions */
		require_once( GPEX_PLUGIN_DIR . '/includes/gpex-admin-functions.php' );

		/** Help content & other stuff */
		require_once( GPEX_PLUGIN_DIR . '/includes/gpex-admin-extras.php' );

		/** Inpost custom CSS stuff */
		if ( function_exists( 'genesis_get_custom_field' )
			&& current_user_can( ddw_gpex_inpost_custom_css_cap() )
		) {
			require_once( GPEX_PLUGIN_DIR . '/includes/gpex-inpost-custom-css.php' );
		}

	} else {

		/** Load frontend only stuff */
		require_once( GPEX_PLUGIN_DIR . '/includes/gpex-frontend.php' );

	}  // end-if is_admin() check

	/** Register additional widget areas */
	require_once( GPEX_PLUGIN_DIR . '/includes/gpex-widget-areas.php' );

	/** Add "Settings" links to plugin page */
	if ( is_admin() && current_user_can( 'manage_options' ) ) {

		add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ) , 'ddw_gpex_settings_page_link' );

	} // end-if is_admin() plus cap check

	/** Additional stuff, only if Prose is active */
	if ( defined( 'PROSE_DOMAIN' ) ) {

		/** Shortcodes */
		require_once( GPEX_PLUGIN_DIR . '/includes/gpex-shortcodes.php' );

		/** Custom CSS inpost screens */
		add_post_type_support( 'post', 'gpex-inpost-css' );
		add_post_type_support( 'page', 'gpex-inpost-css' );

		/** Layout extras */
		require_once( GPEX_PLUGIN_DIR . '/includes/gpex-layout-extras.php' );

	}  // end-if Prose check

}  // end of function ddw_gpex_init


add_action( 'genesis_init', 'ddw_gpex_admin_init', 11 );
/**
 * Load plugin's admin settings page - only within 'wp-admin'.
 * 
 * @since 1.0.0
 *
 * @uses  is_admin()
 */
function ddw_gpex_admin_init() {

	/** If in 'wp-admin' include admin settings & help tabs */
	if ( is_admin() ) {

		/** Load the settings & help stuff */
		require_once( GPEX_PLUGIN_DIR . '/includes/gpex-admin-settings.php' );
		require_once( GPEX_PLUGIN_DIR . '/includes/gpex-admin-settings-help.php' );

	}  // end-if is_admin check

}  // end of function ddw_gpex_admin_init


add_action( 'after_setup_theme', 'ddw_gpex_template_logic' );
/**
 * Template logic for widgetized Homepage template.
 *
 * @since 1.0.0
 *
 * @uses  is_admin()
 */
function ddw_gpex_template_logic() {

	/** Load stuff only for the frontend */
	if ( ! is_admin()
		&& ( 'genesis' == basename( get_template_directory() ) )
		&& function_exists( 'prose_get_stylesheet_location' )
	) {

		/** Load the template file for is_home/ "Homepage" */
		require_once( GPEX_PLUGIN_DIR . '/includes/gpex-template-loader.php' );

		/** Take control of the is_home/ "Homepage" template loading */
		add_filter( 'template_include', 'ddw_gpex_template_loader', 20 );

	}  // end-if frontend, template & function check

}  // end of function ddw_gpex_template_logic


add_action( 'after_setup_theme', 'ddw_gpex_load_multisite_additions', 1 );
/**
 * Optionally, load plugin file with Multisite specific functions,
 *
 * @since 1.0.0
 *
 * @uses  is_multisite()
 */
function ddw_gpex_load_multisite_additions() {

	/** Optionally, include Multisite specific functions */
	if ( is_multisite() ) {

		require_once( GPEX_PLUGIN_DIR . '/includes/gpex-multisite.php' );

	}  // end-if is_multisite() check

}  // end of function ddw_gpex_load_multisite_additions


add_action( 'init', 'ddw_gpex_better_custom_php' );
/**
 * Helper function to return TRUE or FALSE based on filter.
 *
 * @since 1.0.0
 *
 * @return bool Boolean if feature enabled, otherwise false.
 */
function ddw_gpex_better_custom_php() {
	
	return (bool) apply_filters( 'gpex_filter_better_custom_php', '__return_true' );

}  // end of function ddw_gpex_better_custom_php


add_action( 'after_setup_theme', 'ddw_gpex_load_better_custom_php', 0 );
/**
 * Conditionally load custom function for "a better Custom PHP" section.
 *    Reason: The default Prose "Custom PHP" doesn't work most of the time
 *            because of wrong priorities (it fires way too late).
 *
 * @since 1.0.0
 *
 * @uses  WP_CONTENT_DIR
 * @uses  ddw_gpex_better_custom_php()
 */
function ddw_gpex_load_better_custom_php() {

	/** Setup the file location and name  */
	$gpex_custom_php = WP_CONTENT_DIR . '/uploads/prose/gpex-custom-code.php';

	/** Check if file exists & is readable, if so, load it */
	if ( ddw_gpex_better_custom_php() && is_readable( $gpex_custom_php ) ) {

		require_once( $gpex_custom_php );

	}  // end-if file check

}  // end of function ddw_gpex_load_better_custom_php


/**
 * Returns current plugin's header data in a flexible way.
 *
 * @since  1.0.0
 *
 * @uses   is_admin()
 * @uses   get_plugins()
 * @uses   plugin_basename()
 *
 * @param  $gpex_plugin_value
 * @param  $gpex_plugin_folder
 * @param  $gpex_plugin_file
 *
 * @return string Plugin data.
 */
function ddw_gpex_plugin_get_data( $gpex_plugin_value ) {

	/** Bail early if we are not in wp-admin */
	if ( ! is_admin() ) {
		return;
	}

	/** Include WordPress plugin data */
	if ( ! function_exists( 'get_plugins' ) ) {
		require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	}

	$gpex_plugin_folder = get_plugins( '/' . plugin_basename( dirname( __FILE__ ) ) );
	$gpex_plugin_file = basename( ( __FILE__ ) );

	return $gpex_plugin_folder[ $gpex_plugin_file ][ $gpex_plugin_value ];

}  // end of function ddw_gpex_plugin_get_data