<?php
/**
 * Helper functions for the admin's settings page - plugin links and help tabs.
 *
 * @package    Genesis Prose Extras
 * @subpackage Admin Settings
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright (c) 2013, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL-2.0+
 * @link       http://genesisthemes.de/en/wp-plugins/genesis-prose-extras/
 * @link       http://deckerweb.de/twitter
 *
 * @since      1.0.0
 */

/**
 * Prevent direct access to this file.
 *
 * @since 1.0.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


/**
 * Add help tab content for Genesis Prose Extras Plugin.
 *
 * @since 1.0.0
 *
 * @uses  ddw_gpex_plugin_get_data() To display various data of this plugin.
 */
function ddw_gpex_plugin_start_help() {

	echo '<h3>' . __( 'Plugin', 'genesis-prose-extras' ) . ': ' . __( 'Genesis Prose Extras', 'genesis-prose-extras' ) . ' <small>v' . esc_attr( ddw_gpex_plugin_get_data( 'Version' ) ) . '</small></h3>';

	echo ddw_gpex_help_content_plugin_info();

	echo '<p><a href="http://www.opensource.org/licenses/gpl-license.php" target="_new" title="' . esc_attr( GPEX_PLUGIN_LICENSE ). '">' . esc_attr( GPEX_PLUGIN_LICENSE ). '</a> &copy; ' . date( 'Y' ) . ' <a href="' . esc_url( ddw_gpex_plugin_get_data( 'AuthorURI' ) ) . '" target="_new" title="' . esc_attr__( ddw_gpex_plugin_get_data( 'Author' ) ) . '">' . esc_attr__( ddw_gpex_plugin_get_data( 'Author' ) ) . '</a></p>';

}  // end of function ddw_gpex_plugin_start_help


/**
 * Helper function for echoing the sub headline for help content as HTML string
 *    with specific sub head paramter (title/ subject).
 *
 * @since 1.0.0
 *
 * @param $gpex_subhead
 */
function ddw_gpex_help_content_sub_head( $gpex_subhead = '' ) {

	echo sprintf(
		'<h3>%1$s: %2$s</h3>',
		__( 'Genesis Prose Extras', 'genesis-prose-extras' ),
		esc_attr( $gpex_subhead )
	);

}  // end of function ddw_gpex_help_content_sub_head


/**
 * Add help tab content for Widget Areas.
 *
 * @since 1.0.0
 *
 * @uses  ddw_gpex_help_content_sub_head()
 * @uses  ddw_gpex_plugin_help_content_widget_areas()
 */
function ddw_gpex_widget_areas_help() {

	ddw_gpex_help_content_sub_head( __( 'Widget Areas', 'genesis-prose-extras' ) );

	echo ddw_gpex_help_content_widget_areas();

}  // end of function ddw_gpex_widget_areas_help


/**
 * Add help tab content for Custom CSS (inpost screens).
 *
 * @since 1.0.0
 *
 * @uses  ddw_gpex_help_content_sub_head()
 * @uses  ddw_gpex_help_content_custom_css_advice()
 */
function ddw_gpex_custom_css_help() {

	ddw_gpex_help_content_sub_head( __( 'Custom CSS', 'genesis-prose-extras' ) );

	ddw_gpex_help_content_custom_css_advice();

}  // end of function ddw_gpex_custom_css_help


/**
 * Add help tab content for Layout Extras.
 *
 * @since 1.1.0
 *
 * @uses  ddw_gpex_help_content_sub_head()
 * @uses  ddw_gpex_help_content_layouts_info()
 */
function ddw_gpex_layout_extras_help() {

	ddw_gpex_help_content_sub_head( __( 'Layouts', 'genesis-prose-extras' ) );

	ddw_gpex_help_content_layouts_info();

}  // end of function ddw_gpex_layout_extras_help


/**
 * Add help tab content for Shortcodes.
 *
 * @since 1.0.0
 *
 * @uses  ddw_gpex_help_content_sub_head()
 * @uses  ddw_gpex_help_content_shortcodes_params()
 */
function ddw_gpex_shortcodes_help() {

	ddw_gpex_help_content_sub_head( __( 'Shortcodes', 'genesis-prose-extras' ) );

	ddw_gpex_help_content_shortcodes_params();

}  // end of function ddw_gpex_shortcodes_help


/**
 * Add help tab content for Multisite install extras.
 *
 * @since  1.0.0
 *
 * @uses   prose_get_stylesheet_location()
 * @uses   ddw_gpex_help_content_sub_head()
 *
 * @param  $gpex_multisite_path
 *
 * @global mixed $blog_id
 */
function ddw_gpex_multisite_help() {

	/** Get the Site/ Blog ID */
	global $blog_id;

	/** Set the functions file path */
	$gpex_multisite_path = prose_get_stylesheet_location( 'path' ) . 'functions-site-' . $blog_id . '.php';

	/** The help content */
	ddw_gpex_help_content_sub_head( __( 'Multisite Extras', 'genesis-prose-extras' ) );

	echo '<h4>' . __( 'Load and use extra Site specific functions files.', 'genesis-prose-extras' ) . ' &rarr; ' . __( 'Usage', 'genesis-prose-extras' ) . ':</h4>' .
		'<p>' . sprintf( __( 'Place a special named functions file in the following path for this sub site (ID: %s) that is using the Prose child theme.', 'genesis-prose-extras' ), '<code>' . $blog_id . '</code>' ) .
		'<br />&rarr; ' . sprintf( __( 'File name: %s', 'genesis-prose-extras' ), '<code>functions-site-<strong>' . $blog_id . '</strong>.php</code>' ) .
		'<br />&rarr; ' . sprintf( __( 'File path: %s', 'genesis-prose-extras' ), '<code>' . $gpex_multisite_path . '</code>' ) . '</p>' .
		'<p>' . __( 'Note: The same principle applies for any sub site that is using the same Prose (main) child theme.', 'genesis-prose-extras' ) . '</p>';

}  // end of function ddw_gpex_multisite_help


/**
 * Add help tab content for Plugin Translations.
 *
 * @since 1.0.0
 *
 * @uses  ddw_gpex_help_content_sub_head()
 * @uses  get_locale()
 */
function ddw_gpex_plugin_translations_help() {

	ddw_gpex_help_content_sub_head( __( 'Translations', 'genesis-prose-extras' ) );

	echo '<p>' . sprintf( __( 'Please contribute to existing or new translations on %sour free translations platform%s powered by GlotPress.', 'genesis-prose-extras' ), '<a href="' . esc_url( GPEX_URL_TRANSLATE ) . '" target="_new" title="' . __( 'Translations', 'genesis-prose-extras' ) . '"><strong>', '</strong></a>' ) . '</p>' .
		'<p><blockquote><strong><em>&mdash; ' . __( 'Thank You!', 'genesis-prose-extras' ) . '</em></strong></blockquote></p>';

	if ( get_locale() == 'de_DE' || get_locale() == 'de_AT' || get_locale() == 'de_CH' || get_locale() == 'de_LU' ) {
		$gpex_language_in_use = '<em> (' . __( 'Currently in use', 'genesis-prose-extras' ) . ' :)</em>';
	} else {
		$gpex_language_in_use = '';
	}

	echo '<br /><p><strong>' . __( 'Currently available languages', 'genesis-prose-extras' ) . ':</strong></p>' .
		'<ul>' .
			'<li>' . __( 'English (en_US)', 'genesis-prose-extras' ) . ' &ndash; ' . __( 'default, always included (by David Decker)', 'genesis-prose-extras' ) . '</li>' .
			'<li>' . __( 'German (de_DE): Deutsch', 'genesis-prose-extras' ) . ' &ndash; ' . __( 'always included (by David Decker)', 'genesis-prose-extras' ) . $gpex_language_in_use . '</li>' .
		'</ul>';

}  // end of function ddw_gpex_plugin_translations_help


/**
 * Add help tab content for Recommended Plugins.
 *
 * @since 1.0.0
 */
function ddw_gpex_recommended_plugins_help() {

	echo '<h3>' . __( 'Recommended Plugins', 'genesis-prose-extras' ) . '</h3>';

	echo __( 'Optional extensions to get the best out of your Prose child theme.', 'genesis-prose-extras' );

	echo '<ul>';

		if ( ! defined( 'GWAT_PLUGIN_BASEDIR' ) ) {
			echo '<li><a href="http://wordpress.org/plugins/genesis-widgetized-archive/" target="_new" title="Genesis Widgetized Archive ...">Genesis Widgetized Archive</a><br /><small>' . __( 'Finally, use widgets to maintain &amp; customize your Archive Page Template in Genesis Framework and Child Themes to create archive or sitemap-like listings.', 'genesis-prose-extras' ) . '</small></li>';
			$gpex_help_plugins = 'not_installed';
		}

		if ( ! defined( 'GWNF_PLUGIN_BASEDIR' ) ) {
			echo '<li><a href="http://wordpress.org/plugins/genesis-widgetized-notfound/" target="_new" title="Genesis Widgetized Not Found & 404 ...">Genesis Widgetized Not Found & 404</a><br /><small>' . __( 'Easily add widgets for these two not found edge cases. Then you\'re prepared! Again, changing content then is really easy!', 'genesis-prose-extras' ) . '</small></li>';
			$gpex_help_plugins = 'not_installed';
		}

		if ( ! defined( 'GLE_PLUGIN_BASEDIR' ) ) {
			echo '<li><a href="http://wordpress.org/plugins/genesis-layout-extras/" target="_new" title="Genesis Layout Extras ...">Genesis Layout Extras</a><br /><small>' . __( 'If you want to change the default layout option for some special pages or areas, use this plugin.', 'genesis-prose-extras' ) . '</small></li>';
			$gpex_help_plugins = 'not_installed';
		}

		if ( ! defined( 'GPSP_PLUGIN_BASEDIR' ) ) {
			echo '<li><a href="http://wordpress.org/plugins/genesis-printstyle-plus/" target="_new" title="Genesis Printstyle Plus ...">Genesis Printstyle Plus</a><br /><small>' . __( 'Print out your content easily - unneeded sections are removed.', 'genesis-prose-extras' ) . '</small></li>';
			$gpex_help_plugins = 'not_installed';
		}

		if ( ! defined( 'GTBE_PLUGIN_BASEDIR' ) ) {
			echo '<li><a href="http://wordpress.org/plugins/genesis-toolbar-extras/" target="_new" title="Genesis Toolbar Extras ...">Genesis Toolbar Extras</a><br /><small>' . __( 'Manage Genesis Framework, active child theme and extensions from your WordPress toolbar. Massive resources links included!', 'genesis-prose-extras' ) . '</small></li>';
			$gpex_help_plugins = 'not_installed';
		}

		if ( ! defined( 'GEST_PLUGIN_BASEDIR' ) ) {
			echo '<li><a href="http://wordpress.org/plugins/genesis-extra-settings-transporter/" target="_new" title="Genesis Extra Settings Transporter ...">Genesis Extra Settings Transporter</a><br /><small>' . __( 'Adds support for exporting settings of various Genesis specific plugins & Child Themes via the Genesis Exporter feature.', 'genesis-prose-extras' ) . '</small></li>';
			$gpex_help_plugins = 'not_installed';
		}

		if ( 'not_installed' != $gpex_help_plugins  ) {
			echo '<li><em>' . __( 'Perfect, you already have all our recommended plugins installed.', 'genesis-prose-extras' ) . '</em></li>';
		}

	echo '</ul>';

}  // end of function ddw_gpex_recommended_plugins_help