<?php
/**
 * Load layout/ frontend relevant functions/ logic for Prose Child Theme.
 *
 * @package    Genesis Prose Extas
 * @subpackage Frontend/ Layouts
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright (c) 2013, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL-2.0+
 * @link       http://genesisthemes.de/en/wp-plugins/genesis-prose-extras/
 * @link       http://deckerweb.de/twitter
 *
 * @since      1.0.0
 */

/**
 * Prevent direct access to this file.
 *
 * @since 1.0.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


add_action( 'init', 'ddw_gpex_register_additional_layouts' );
/**
 * Register additional layout options for Prose Child Theme.
 *
 * @since 1.0.0
 *
 * @uses  genesis_get_option()
 * @uses  genesis_register_layout()
 */
function ddw_gpex_register_additional_layouts() {

	/** Layout: Sidebars below Content (like a special "Full-Width-Content" flavor :) */
	if ( function_exists( 'genesis_get_option' ) && genesis_get_option( 'layout_sbc', 'gpex-settings' ) ) {

		genesis_register_layout( 'sidebars-below-content', array(
			'label' => __( 'Sidebars below Content', 'genesis-prose-extras' ),
			'img'   => apply_filters( 'gpex_filter_layout_image_sidebars_below_content', esc_url( plugins_url( 'images/gpex_sbc.gif', dirname( __FILE__ ) ) ) ),
		) );

	}  // end-if settings check

	/** Layout: Content/Sidebar-Alt (like a special "Content-Sidebar" flavor :) */
	if ( function_exists( 'genesis_get_option' ) && genesis_get_option( 'layout_c_salt', 'gpex-settings' ) ) {

		genesis_register_layout( 'content-sidebaralt', array(
			'label' => __( 'Content/Sidebar-Alt', 'genesis-prose-extras' ),
			'img'   => apply_filters( 'gpex_filter_layout_image_content_sidebaralt', esc_url( plugins_url( 'images/gpex_c-salt.gif', dirname( __FILE__ ) ) ) ),
		) );

	}  // end-if settings check

	/** Layout: Sidebar-Alt/Content (like a special "Sidebar-Content" flavor :) */
	if ( function_exists( 'genesis_get_option' ) && genesis_get_option( 'layout_salt_c', 'gpex-settings' ) ) {

		genesis_register_layout( 'sidebaralt-content', array(
			'label' => __( 'Sidebar-Alt/Content', 'genesis-prose-extras' ),
			'img'   => apply_filters( 'gpex_filter_layout_image_sidebaralt_content', esc_url( plugins_url( 'images/gpex_salt-c.gif', dirname( __FILE__ ) ) ) ),
		) );

	}  // end-if settings check

}  // end of function ddw_gpex_register_additional_layouts


/**
 * Helper function for returning layout key 'sidebars-below-content'.
 *
 * @since  1.0.0
 *
 * @return string 'sidebars-below-content'
 */
function __gpex_return_sidebars_below_content() {

	return 'sidebars-below-content';

}  // end of function __gpex_return_sidebars_below_content


/**
 * Helper function for returning layout key 'content-sidebaralt'.
 *
 * @since  1.0.0
 *
 * @return string 'content-sidebaralt'
 */
function __gpex_return_content_sidebaralt() {

	return 'content-sidebaralt';

}  // end of function __gpex_return_content_sidebaralt


/**
 * Helper function for returning layout key 'sidebaralt-content'.
 *
 * @since  1.0.0
 *
 * @return string 'sidebaralt-content'
 */
function __gpex_return_sidebaralt_content() {

	return 'sidebaralt-content';

}  // end of function __gpex_return_sidebaralt_content