<?php
/**
 * Shortcodes for frontend display.
 *
 * @package    Genesis Prose Extras
 * @subpackage Shortcodes
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright (c) 2013, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL-2.0+
 * @link       http://genesisthemes.de/en/wp-plugins/genesis-prose-extras/
 * @link       http://deckerweb.de/twitter
 *
 * @since      1.0.0
 */

/**
 * Prevent direct access to this file.
 *
 * @since 1.0.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


add_shortcode( 'gpex_author_posts_link', 'ddw_gpex_post_author_posts_link_shortcode' );
/**
 * Creates an author posts link short code that works outside the loop.
 *
 * @since  1.0.0
 *
 * @uses   shortcode_atts()
 * @uses   genesis_html5()
 * @uses   get_the_author_meta()
 * @uses   get_author_posts_url()
 * @uses   get_the_author_meta()
 * @uses   genesis_attr()
 *
 * @param  array 	$defaults 	Default values of Shortcode parameters.
 * @param  array 	$atts 		Attributes passed from Shortcode.
 * @param  string 	$author_id
 * @param  string 	$author_name
 * @param  string 	$author_url
 * @param  string 	$link_author
 * @param  string 	$output
 *
 * @global $post, $wp_query
 *
 * @return string HTML content of the shortcode.
 */
function ddw_gpex_post_author_posts_link_shortcode( $atts ) {
  
	global $post, $wp_query;

	/** Set default shortcode attributes */
	$defaults = array(
		'after'  => '',
		'before' => '',
	);

	/** Default shortcode attributes */
	$atts = shortcode_atts( $defaults, $atts, 'gpex_author_posts_link' );

	$author_id   = $wp_query->posts[0]->post_author;
	$author_name = get_the_author_meta( 'display_name', $author_id );
	$author_url  = get_author_posts_url( get_the_author_meta( 'ID' ) );

	if ( function_exists( 'genesis_html5' ) && genesis_html5() ) {

		$output  = sprintf( '<span %s>', genesis_attr( 'entry-author' ) );
		$output .= $atts[ 'before' ];
		$output .= sprintf(
			'<a href="%s" %s>',
			$author_url,
			genesis_attr( 'entry-author-link' )
		);
		$output .= sprintf( '<span %s>', genesis_attr( 'entry-author-name' ) );
		$output .= esc_html( $author_name );
		$output .= '</span></a>' . $atts[ 'after' ] . '</span>';

	} else {

		$link_author = sprintf(
			'<a href="%1$s" class="fn n" title="%2$s" rel="author">%3$s</a>',
			esc_url( $author_url ),
			esc_attr( $author_name ),
			esc_html( $author_name )
		);

		$output = sprintf(
			'<span class="author vcard">%2$s<span class="fn">%1$s</span>%3$s</span>',
			$link_author,
			$atts[ 'before' ],
			$atts[ 'after' ]
		);

	}  // end-if

	/** Return Shortcode's HTML - filterable */
	return apply_filters( 'gpex_filter_post_author_posts_link_shortcode', $output, $atts );

}  // end of function ddw_gpex_post_author_posts_link_shortcode


add_shortcode( 'gpex_post_categories', 'ddw_gpex_post_categories_shortcode' );
/**
 * Creates a short code that will display your post categories inside or outside
 *    the loop. Maintains parent/child category hierarchy.
 *
 * @since  1.0.0
 *
 * @param  array 	$defaults 	Default values of Shortcode parameters.
 * @param  array 	$atts 		Attributes passed from Shortcode.
 * @param  string 	$output
 *
 * @global $post
 *
 * @return string HTML content of the shortcode.
 */
function ddw_gpex_post_categories_shortcode( $atts ) {

	/** Load translations to display for the activation message. */
	load_plugin_textdomain( 'genesis-prose-extras', false, GPEX_LANG_DIR );
	
	global $post;

	/** Set default shortcode attributes */
	$defaults = array(
		'sep'    => ', ',
		'before' => __( 'Categories: ', 'genesis-prose-extras' ),
		'after'  => '',
		'class'  => '',	// easter egg :)
	);
	
	/** Default shortcode attributes */
	$atts = shortcode_atts( $defaults, $atts, 'gpex_post_categories' );

	/** Separator */
	$sep  = $atts[ 'sep' ];
	
	/** Category IDs */
	$cat_ids = implode( ',', wp_get_post_categories( $post->ID, array( 'fields' => 'ids' ) ) );
	
	/** Categories */
	$cats = wp_list_categories( 'title_li=&style=none&echo=0&include=' . $cat_ids );
	$cats = rtrim( trim( str_replace( '<br />',  $sep, $cats ) ), $sep );
	$cats = str_replace( array( "\n", "\r", "\t" ), "", $cats );
  
  	/** Prepare the shortcode frontend output */
  	if ( function_exists( 'genesis_html5' ) && genesis_html5() ) {

		$output = sprintf( '<span %s>', genesis_attr( 'entry-categories' ) ) . $atts[ 'before' ] . $cats . $atts[ 'after' ] . '</span>';

	} else {

		$output = sprintf(
			'<span class="categories%4$s">%2$s%1$s%3$s</span>',
			! empty( $atts[ 'class' ] ) ? ' ' . esc_attr( $atts[ 'class' ] ) : '',
			$atts[ 'before' ],
			$cats,
			$atts[ 'after' ]
		);

	}  // end-if

	/** Return Shortcode's HTML - filterable */
	return apply_filters( 'gpex_filter_post_categories_shortcode', $output, $atts );

}  // end of function ddw_gpex_post_categories_shortcode


add_shortcode( 'gpex_widget_area', 'ddw_gpex_shortcode_widget_area' );
/**
 * Display one of our 4 widget areas (only if active) via Shortcode.
 *
 * @since  1.0.0
 *
 * @uses   shortcode_atts()
 * @uses   is_active_sidebar()
 * @uses   gpex_display_404_widget()
 * @uses   dynamic_sidebar()
 * @uses   ob_start()
 * @uses   ob_get_contents()
 * @uses   ob_get_clean()
 *
 * @param  array 	$atts
 * @param  array 	$defaults
 * @param  string 	$area_output
 * @param  string 	$output
 *
 * @return string HTML String of Widget area.
 */
function ddw_gpex_shortcode_widget_area( $atts ) {

	/** Set default shortcode attributes */
	$defaults = array(
		'area' => '',
	);

	/** Default shortcode attributes */
	$atts = shortcode_atts( $defaults, $atts, 'gpex_widget_area' );

	/**
	 * Start Output Buffering - we have no other chance, otherwise widget areas
	 *    would glue at the top of content...
	 */
	ob_start();

	/** If our parameter is not empty: */
	if ( ! empty( $atts[ 'area' ] ) ) {

		/** Check for one of the 6 areas: */
		if ( in_array( $atts[ 'area' ], array( 'gpex-prose-home-top', 'gpex-prose-home-left', 'gpex-prose-home-right', 'gpex-prose-home-extra', 'gpex-prose-after-page' ) )
			&& is_active_sidebar( $atts[ 'area' ] )
		) {

			$area_output = sprintf(
				'%1$s%2$s%3$s',
				'<div id="' . $atts[ 'area' ] . '" class="' . $atts[ 'area' ] . ' entry-content">',
				dynamic_sidebar( $atts[ 'area' ] ),
				'</div>'
			);

		} elseif ( ( $atts[ 'area' ] == 'prose-after-post' || $atts[ 'area' ] == 'after-post' )
					&& is_active_sidebar( 'after-post' )
		) {

			$area_output = sprintf(
				'%1$s%2$s%3$s',
				'<div id="gpex-prose-after-post" class="after-post entry-content">',
				dynamic_sidebar( 'after-post' ),
				'</div>'
			);

		} else {

			$area_output = '';

		}  // end-if area check

	}  // end-if parameter check

	/** Get content from the output buffer, without deleting */
	$output = ob_get_contents();

	/** End output buffer */
	return ob_get_clean();

	/** Return the output - filterable */
	return apply_filters( 'gpex_filter_shortcode_widget_area', $output );

}  // end of function ddw_gpex_shortcode_widget_area


add_shortcode( 'gpex_affiliate', 'ddw_gpex_shortcode_affiliate_sas' );
/**
 * Create simple "Share a Sale" affiliate link for Prose or Genesis.
 *
 * @since  1.0.0
 *
 * @uses   shortcode_atts()
 *
 * @param  array 	$atts
 * @param  array 	$defaults
 * @param  string 	$item_url
 * @param  string 	$output
 *
 * @return string HTML String of affiliate link.
 */
function ddw_gpex_shortcode_affiliate_sas( $atts ) {

	/** Load translations to display for the activation message. */
	load_plugin_textdomain( 'genesis-prose-extras', false, GPEX_LANG_DIR );

	/** Set default shortcode attributes */
	$defaults = array(
		'item'      => '',
		'sas'       => '',
		'link_text' => sprintf( __( 'Get %s', 'genesis-prose-extras' ), $atts[ 'item' ] ),
		'target'    => 'new',
		'class'     => '',
	);

	/** Default shortcode attributes */
	$atts = shortcode_atts( $defaults, $atts, 'gpex_affiliate' );

	/** Setup the SaS aff links */
	if ( strtolower( $atts[ 'item' ] ) == 'prose' ) {

		$item_url = 'http://www.shareasale.com/r.cfm?B=255475&U=' . esc_attr( $atts[ 'sas' ] ) . '&M=28169&urllink=';

	} elseif ( strtolower( $atts[ 'item' ] ) == 'genesis' ) {

		$item_url = 'http://www.shareasale.com/r.cfm?B=242694&U=' . esc_attr( $atts[ 'sas' ] ) . '&M=28169&urllink=';

	}  // end-if

	$output = sprintf(
		'<a%1$s href="%2$s" target="_%3$s" title="%4$s">%5$s</a>',
		! empty( $atts[ 'class' ] ) ? ' class="' . esc_attr( $atts[ 'class' ] ) . '"' : '',
		esc_url( $item_url ),
		esc_attr( $atts[ 'target' ] ),
		esc_html( $atts[ 'link_text' ] ),
		esc_attr( $atts[ 'link_text' ] )
	);

	/** Return Shortcode's HTML - filterable */
	return apply_filters( 'gpex_filter_affiliate_shortcode', $output, $atts );

}  // end of function ddw_gpex_shortcode_affiliate_sas