<?php
/**
 * Translations helper functions.
 *
 * @package    Genesis Prose Extras
 * @subpackage i18n
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright (c) 2013, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL-2.0+
 * @link       http://genesisthemes.de/en/wp-plugins/genesis-prose-extras/
 * @link       http://deckerweb.de/twitter
 *
 * @since      1.0.0
 */

/**
 * Prevent direct access to this file.
 *
 * @since 1.0.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


add_action( 'after_setup_theme', 'ddw_gpex_load_prose_translations' );
/**
 * Load the default or customized translations for "Prose" child theme.
 *    - Overrides translations if still existing in child theme's
 *      '/lib/languages/' folder.
 *    - Load formal or informal translations as set on settings page.
 *    - Supports storing translations in subfolders of WP_LANG_DIR to avoid
 *      overriding on plugin updates!
 *
 * @since  1.0.0
 *
 * @uses   genesis_get_option()
 * @uses   get_locale()
 * @uses   load_textdomain()
 *
 * @param  $mofile
 *
 * @global mixed $locale
 */
function ddw_gpex_load_prose_translations() {

	/** Check for Genesis function, otherwise bail early */
	if ( ! function_exists( 'genesis_get_option' ) ) {
		return;
	}

	/** Get global Locale variable */
	global $locale;

	/**
	 * 1st: Prose formal
	 */
	if ( genesis_get_option( 'formal_translations', 'gpex-settings' ) ) {

		/** Check for formal version */
		if ( is_readable( WP_LANG_DIR . '/prose-theme/formal/' . get_locale() . '.mo' ) ) {

			$mofile = WP_LANG_DIR . '/prose-theme/formal/' . apply_filters( 'gpex_filter_prose_wplang_formal_locale', '' . get_locale() ) . '.mo';

		}

		/** Then check for custom version */
		elseif ( is_readable( WP_LANG_DIR . '/prose-theme/custom/' . get_locale() . '.mo' ) ) {

			$mofile = WP_LANG_DIR . '/prose-theme/custom/' . apply_filters( 'gpex_filter_prose_wplang_custom_locale', '' . get_locale() ) . '.mo';

		}

		/** Otherwise load plugin default */
		else {

			$mofile = WP_PLUGIN_DIR . '/genesis-prose-extras/prose-pomo/formal/' . apply_filters( 'gpex_filter_prose_plugin_formal_locale', '' . get_locale() ) . '.mo';

		}  // end-if file checks

	/**
	 * 2nd: Prose informal
	 */
	} elseif ( ! genesis_get_option( 'formal_translations', 'gpex-settings' ) ) {

		/** Check for informal version */
		if ( is_readable( WP_LANG_DIR . '/prose-theme/informal/' . get_locale() . '.mo' ) ) {

			$mofile = WP_LANG_DIR . '/prose-theme/informal/' . apply_filters( 'gpex_filter_prose_wplang_informal_locale', '' . get_locale() ) . '.mo';

		}

		/** Then check for custom version */
		elseif ( is_readable( WP_LANG_DIR . '/prose-theme/custom/' . get_locale() . '.mo' ) ) {

			$mofile = WP_LANG_DIR . '/prose-theme/custom/' . apply_filters( 'gpex_filter_prose_wplang_custom_locale', '' . get_locale() ) . '.mo';

		}

		/** Otherwise load plugin default */
		else {

			$mofile = WP_PLUGIN_DIR . '/genesis-prose-extras/prose-pomo/informal/' . apply_filters( 'gpex_filter_prose_plugin_informal_locale', '' . get_locale() ) . '.mo';

		}  // end-if file checks

	}  // end-if/elseif

	/** Finally, load the translations */
	if ( file_exists( $mofile ) ) {

		return load_textdomain( 'prose', $mofile );

	}  // end-if $mofile check

}  // end of function ddw_gpex_load_prose_translations