<?php
/**
 * Helper function to delete plugin's options array on plugin deletion.
 *
 * @package    Genesis Prose Extras
 * @subpackage Uninstall
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright (c) 2013, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL-2.0+
 * @link       http://genesisthemes.de/en/wp-plugins/genesis-prose-extras/
 * @link       http://deckerweb.de/twitter
 *
 * @since      1.0.0
 */

/**
 * Prevent direct access to this file.
 *
 * @since 1.0.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


/**
 * If uninstall not called from WordPress, exit.
 *
 * @since 1.0.0
 *
 * @uses  WP_UNINSTALL_PLUGIN
 */
if ( ! defined( 'WP_UNINSTALL_PLUGIN' ) ) {
	exit();
}


/**
 * Delete our options array (settings field) from the database.
 *    Note: Respects Multisite setups and single installs.
 *
 * @since 1.0.0
 *
 * @uses  switch_to_blog()
 * @uses  delete_option()
 *
 * @param array $blogs
 * @param int 	$blog
 *
 * @global $wpdb
 */
/** First, check for Multisite, if yes, delete options on a per site basis */
if ( is_multisite() ) {

    global $wpdb;

    /** Get array of Site/Blog IDs from the database */
    $blogs = $wpdb->get_results( "SELECT blog_id FROM {$wpdb->blogs}", ARRAY_A );

    if ( $blogs ) {

        foreach ( $blogs as $blog ) {

        	/** Repeat for every Site ID */
            switch_to_blog( $blog[ 'blog_id' ] );

            delete_option( 'gpex-settings' );

        }  // end foreach

        restore_current_blog();

    }  // end-if

}

/** Otherwise, delete options from main options table */
else {

    delete_option( 'gpex-settings' );

}  // end-if